// Copyright (c) 2005-2010 StreamBase Systems, Inc. All rights reserved.
package com.streambase.contrib.eclipse.connectivity;

import java.util.Collection;

import org.eclipse.core.runtime.IStatus;

import com.streambase.sb.Schema;
import com.streambase.sb.StreamBaseException;
import com.streambase.sb.Tuple;
import com.streambase.sb.client.DequeueResult;
import com.streambase.sb.client.StreamBaseClient;
import com.streambase.sb.client.StreamBaseURI;

public interface ISBConnection {

	/**
	 * A request to connect to the target StreamBase server identified by the passed in StreamBase URI.
	 * A connection check is made immediately, however, connection failures after this call returns
	 * happen asynchronously and are not actively reported.  
	 * @param server the server to connect to
	 * @throws StreamBaseException thrown on initial connection error
	 * @throws IllegalStateException thrown if this is called while already connected
	 */
	public void connectTo(StreamBaseURI server) throws StreamBaseException, IllegalStateException;
	public void disconnect();

	public StreamBaseClient getDequeueClient();
	public StreamBaseClient getEnqueueClient();
	
	/**
	 * @param l a listener notified when a dequeue result arrives from the Server. The status of the result will always be {@link DequeueResult#GOOD}
	 */
	public void addDequeueListener(ISBDequeueListener l);
	
	/**
	 * Get the collection of dq streams that were declared in the extension point.
	 * @TestingUse
	 * @return the array of stream names that were declared
	 */
	public String[] getInitialDequeueStreams();
	
	/**
	 * @param l remove this listener
	 */
	public void removeDequeueListener(ISBDequeueListener l);
	
	/**
	 * Enqueue a tuple onto a stream
	 * @param stream The stream to enqueue on
	 * @param tuple The tuple to enqueue
	 * @throws StreamBaseException thrown if there is a problem enqueueing the tuple
	 */
	public void enqueue (String stream, Tuple tuple) throws StreamBaseException;
	
	/**
	 * Enqueue a collection of tuple onto a stream
	 * @param stream The stream to enqueue on
	 * @param tuples The collection of tuples to enqueue
	 * @throws StreamBaseException thrown if there is a problem enqueueing the tuples
	 */
	public void enqueue (String stream, Collection<Tuple> tuples) throws StreamBaseException;
	
	/**
	 * Returns the Schema for the passed input stream name.
	 * @param stream Module qualified stream name
	 * @return the Schema for the passed stream. null if not found.
	 */
	public Schema getInputStreamSchemaFromName(String stream);
	
	/**
	 * Returns the Schema for the passed output stream name.
	 * @param stream Module qualified stream name
	 * @return the Schema for the passed stream. null if not found.
	 */
	public Schema getOutputStreamSchemaFromName(String stream);

	/**
	 * @param l a listener notified when the StreamBase server connection status has changed
	 */
	public void addStatusListener(IStatusListener l);
	
	/**
	 * @param l remove this listener
	 */
	public void removeStatusListener(IStatusListener l);
	
	/**
	 * @return the status of the StreamBase server connection 
	 */
	public IStatus getStatus();
	public StreamBaseURI getTargetURI();
}