// Copyright (c) 2005-2010 StreamBase Systems, Inc. All rights reserved.
package com.streambase.contrib.eclipse.connectivity.internal;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

import com.streambase.sb.Tuple;


/**
 * Each SBTupleHandler contains an Object and a Method belonging to
 * the class of the Object.  This class also includes an "invoke" method
 * calls that Method, passing if the Object as the call's "receiver",
 * along with a Tuple and a String "streamName" argument.
 * @see SBDequeuedTupleDispatcher 
 */
public class SBTupleHandler {
	
	//  --- members ---
	
	protected Object fHandlerObject;
	protected Method fConsumeTupleMethod;
	
	
	// --- constructors ---
	
	public SBTupleHandler (Object handler, Method consumeTupleMethod) {
		fHandlerObject = handler;
		fConsumeTupleMethod = consumeTupleMethod;
	}
	
	
	// --- methods ---
	
	public void invoke (Tuple tuple, String streamName)
		throws IllegalArgumentException, IllegalAccessException, InvocationTargetException
	{
		fConsumeTupleMethod.invoke (fHandlerObject, tuple, streamName);
	}
	
	@Override
	public String toString() {
		return fHandlerObject.getClass().getName() + "#" + fConsumeTupleMethod.getName();
	}
}
